@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.cdk
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.27.0", __name__, "aws-kms@0.27.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.28.0", __name__, "aws-kms@0.28.0.jsii.tgz")
 class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnAlias"):
     def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, alias_name: str, target_key_id: str) -> None:
         props: CfnAliasProps = {"aliasName": alias_name, "targetKeyId": target_key_id}
@@ -165,6 +165,22 @@ class IEncryptionKey(aws_cdk.cdk.IConstruct, jsii.compat.Protocol):
     def export(self) -> "EncryptionKeyImportProps":
         ...
 
+    @jsii.member(jsii_name="grant")
+    def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
+        ...
+
+    @jsii.member(jsii_name="grantDecrypt")
+    def grant_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        ...
+
+    @jsii.member(jsii_name="grantEncrypt")
+    def grant_encrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        ...
+
+    @jsii.member(jsii_name="grantEncryptDecrypt")
+    def grant_encrypt_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        ...
+
 
 class _IEncryptionKeyProxy(jsii.proxy_for(aws_cdk.cdk.IConstruct)):
     __jsii_type__ = "@aws-cdk/aws-kms.IEncryptionKey"
@@ -185,6 +201,22 @@ class _IEncryptionKeyProxy(jsii.proxy_for(aws_cdk.cdk.IConstruct)):
     def export(self) -> "EncryptionKeyImportProps":
         return jsii.invoke(self, "export", [])
 
+    @jsii.member(jsii_name="grant")
+    def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
+        return jsii.invoke(self, "grant", [grantee, actions])
+
+    @jsii.member(jsii_name="grantDecrypt")
+    def grant_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        return jsii.invoke(self, "grantDecrypt", [grantee])
+
+    @jsii.member(jsii_name="grantEncrypt")
+    def grant_encrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        return jsii.invoke(self, "grantEncrypt", [grantee])
+
+    @jsii.member(jsii_name="grantEncryptDecrypt")
+    def grant_encrypt_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
+
 
 @jsii.implements(IEncryptionKey)
 class EncryptionKeyBase(aws_cdk.cdk.Construct, metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/aws-kms.EncryptionKeyBase"):
@@ -208,6 +240,22 @@ class EncryptionKeyBase(aws_cdk.cdk.Construct, metaclass=jsii.JSIIAbstractClass,
     def export(self) -> "EncryptionKeyImportProps":
         ...
 
+    @jsii.member(jsii_name="grant")
+    def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
+        return jsii.invoke(self, "grant", [grantee, actions])
+
+    @jsii.member(jsii_name="grantDecrypt")
+    def grant_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        return jsii.invoke(self, "grantDecrypt", [grantee])
+
+    @jsii.member(jsii_name="grantEncrypt")
+    def grant_encrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        return jsii.invoke(self, "grantEncrypt", [grantee])
+
+    @jsii.member(jsii_name="grantEncryptDecrypt")
+    def grant_encrypt_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
+        return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
+
     @property
     @jsii.member(jsii_name="keyArn")
     @abc.abstractmethod
@@ -280,6 +328,21 @@ class EncryptionKey(EncryptionKeyBase, metaclass=jsii.JSIIMeta, jsii_type="@aws-
         return jsii.get(self, "policy")
 
 
-__all__ = ["CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "EncryptionKey", "EncryptionKeyAlias", "EncryptionKeyAliasProps", "EncryptionKeyBase", "EncryptionKeyImportProps", "EncryptionKeyProps", "IEncryptionKey", "__jsii_assembly__"]
+class ViaServicePrincipal(aws_cdk.aws_iam.PrincipalBase, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.ViaServicePrincipal"):
+    def __init__(self, service_name: str, base_principal: typing.Optional[aws_cdk.aws_iam.IPrincipal]=None) -> None:
+        jsii.create(ViaServicePrincipal, self, [service_name, base_principal])
+
+    @property
+    @jsii.member(jsii_name="policyFragment")
+    def policy_fragment(self) -> aws_cdk.aws_iam.PrincipalPolicyFragment:
+        return jsii.get(self, "policyFragment")
+
+    @property
+    @jsii.member(jsii_name="serviceName")
+    def service_name(self) -> str:
+        return jsii.get(self, "serviceName")
+
+
+__all__ = ["CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "EncryptionKey", "EncryptionKeyAlias", "EncryptionKeyAliasProps", "EncryptionKeyBase", "EncryptionKeyImportProps", "EncryptionKeyProps", "IEncryptionKey", "ViaServicePrincipal", "__jsii_assembly__"]
 
 publication.publish()
